Documentation
¶
Index ¶
Constants ¶
const ( ProtocolSync_SyncProduct_FullMethodName = "/protocolSync.protocolSync/SyncProduct" ProtocolSync_SyncDevice_FullMethodName = "/protocolSync.protocolSync/SyncDevice" )
Variables ¶
var File_proto_protocolSync_proto protoreflect.FileDescriptor
var ProtocolSync_ServiceDesc = grpc.ServiceDesc{ ServiceName: "protocolSync.protocolSync", HandlerType: (*ProtocolSyncServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "SyncProduct", Handler: _ProtocolSync_SyncProduct_Handler, }, { MethodName: "SyncDevice", Handler: _ProtocolSync_SyncDevice_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/protocolSync.proto", }
ProtocolSync_ServiceDesc is the grpc.ServiceDesc for ProtocolSync service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterProtocolSyncServer ¶
func RegisterProtocolSyncServer(s grpc.ServiceRegistrar, srv ProtocolSyncServer)
Types ¶
type Empty ¶
type Empty struct {
// contains filtered or unexported fields
}
func (*Empty) Descriptor
deprecated
func (*Empty) ProtoMessage ¶
func (*Empty) ProtoMessage()
func (*Empty) ProtoReflect ¶
func (x *Empty) ProtoReflect() protoreflect.Message
type ProtocolSyncClient ¶
type ProtocolSyncClient interface {
SyncProduct(ctx context.Context, in *Empty, opts ...grpc.CallOption) (*Empty, error)
SyncDevice(ctx context.Context, in *SyncDeviceReq, opts ...grpc.CallOption) (*SyncDeviceResp, error)
}
ProtocolSyncClient is the client API for ProtocolSync service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewProtocolSyncClient ¶
func NewProtocolSyncClient(cc grpc.ClientConnInterface) ProtocolSyncClient
type ProtocolSyncServer ¶
type ProtocolSyncServer interface {
SyncProduct(context.Context, *Empty) (*Empty, error)
SyncDevice(context.Context, *SyncDeviceReq) (*SyncDeviceResp, error)
// contains filtered or unexported methods
}
ProtocolSyncServer is the server API for ProtocolSync service. All implementations must embed UnimplementedProtocolSyncServer for forward compatibility
type SyncDeviceReq ¶
type SyncDeviceReq struct {
ProductID string `protobuf:"bytes,1,opt,name=productID,proto3" json:"productID,omitempty"` //
// contains filtered or unexported fields
}
func (*SyncDeviceReq) Descriptor
deprecated
func (*SyncDeviceReq) Descriptor() ([]byte, []int)
Deprecated: Use SyncDeviceReq.ProtoReflect.Descriptor instead.
func (*SyncDeviceReq) GetProductID ¶
func (x *SyncDeviceReq) GetProductID() string
func (*SyncDeviceReq) ProtoMessage ¶
func (*SyncDeviceReq) ProtoMessage()
func (*SyncDeviceReq) ProtoReflect ¶
func (x *SyncDeviceReq) ProtoReflect() protoreflect.Message
func (*SyncDeviceReq) Reset ¶
func (x *SyncDeviceReq) Reset()
func (*SyncDeviceReq) String ¶
func (x *SyncDeviceReq) String() string
type SyncDeviceResp ¶
type SyncDeviceResp struct {
DeviceNames []string `protobuf:"bytes,1,rep,name=deviceNames,proto3" json:"deviceNames,omitempty"`
// contains filtered or unexported fields
}
func (*SyncDeviceResp) Descriptor
deprecated
func (*SyncDeviceResp) Descriptor() ([]byte, []int)
Deprecated: Use SyncDeviceResp.ProtoReflect.Descriptor instead.
func (*SyncDeviceResp) GetDeviceNames ¶
func (x *SyncDeviceResp) GetDeviceNames() []string
func (*SyncDeviceResp) ProtoMessage ¶
func (*SyncDeviceResp) ProtoMessage()
func (*SyncDeviceResp) ProtoReflect ¶
func (x *SyncDeviceResp) ProtoReflect() protoreflect.Message
func (*SyncDeviceResp) Reset ¶
func (x *SyncDeviceResp) Reset()
func (*SyncDeviceResp) String ¶
func (x *SyncDeviceResp) String() string
type UnimplementedProtocolSyncServer ¶
type UnimplementedProtocolSyncServer struct {
}
UnimplementedProtocolSyncServer must be embedded to have forward compatible implementations.
func (UnimplementedProtocolSyncServer) SyncDevice ¶
func (UnimplementedProtocolSyncServer) SyncDevice(context.Context, *SyncDeviceReq) (*SyncDeviceResp, error)
func (UnimplementedProtocolSyncServer) SyncProduct ¶
type UnsafeProtocolSyncServer ¶
type UnsafeProtocolSyncServer interface {
// contains filtered or unexported methods
}
UnsafeProtocolSyncServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ProtocolSyncServer will result in compilation errors.